@@ -6,9 +6,5 @@
 #' @return [\code{logical(1)}].
 #' @export
 isScalarNA = function(x) {
-  identical(x, NA) || 
-  identical(x, NA_integer_) || 
-  identical(x, NA_real_) || 
-  identical(x, NA_character_) || 
-  identical(x, NA_complex_)
-}
\ No newline at end of file
+  is.atomic(x) && length(x) == 1L && is.na(x)
+}
