@@ -20,8 +20,11 @@ warningf = function(..., immediate=TRUE, warning.length=8170L) {
   msg = sprintf(...)
   if (immediate) {
     old = getOption("warn")
-    on.exit(options(warn=old))
-    options(warn=1L)
+    # dont change warn setting if it is 2 (= error)
+    if (old <= 0L) {
+      on.exit(options(warn=old))
+      options(warn=1L)
+    }
   }
   obj = simpleWarning(msg, call=sys.call(sys.parent()))
   warning(obj)
